@@ -14,3 +14,5 @@ user_pref("browser.contentblocking.category", "strict");
 user_pref("privacy.clearOnShutdown.offlineApps", false);
 user_pref("privacy.sanitize.sanitizeOnShutdown", false);
 user_pref("privacy.sanitize.timeSpan", 1);
+user_pref("browser.translations.automaticallyPopup", false);
+user_pref("browser.link.open_newwindow", 2);
